Module blaxel.core.client.models.create_job_execution_response
==============================================================

Classes
-------

`CreateJobExecutionResponse(execution_id: blaxel.core.client.types.Unset | str = <blaxel.core.client.types.Unset object>, id: blaxel.core.client.types.Unset | str = <blaxel.core.client.types.Unset object>, job_id: blaxel.core.client.types.Unset | str = <blaxel.core.client.types.Unset object>, tasks: blaxel.core.client.types.Unset | list['CreateJobExecutionResponseTasksItem'] = <blaxel.core.client.types.Unset object>, workspace_id: blaxel.core.client.types.Unset | str = <blaxel.core.client.types.Unset object>)`
:   Response for creating a job execution
    
    Attributes:
        execution_id (Union[Unset, str]): Execution ID
        id (Union[Unset, str]): Unique message ID
        job_id (Union[Unset, str]): Job ID
        tasks (Union[Unset, list['CreateJobExecutionResponseTasksItem']]): Array of task parameters for parallel
            execution
        workspace_id (Union[Unset, str]): Workspace ID
    
    Method generated by attrs for class CreateJobExecutionResponse.

    ### Static methods

    `from_dict(src_dict: dict[str, typing.Any]) ‑> ~T`
    :

    ### Instance variables

    `additional_keys: list[str]`
    :

    `additional_properties`
    :

    `execution_id`
    :

    `id`
    :

    `job_id`
    :

    `tasks`
    :

    `workspace_id`
    :

    ### Methods

    `to_dict(self) ‑> dict[str, typing.Any]`
    :